@@ -1,6 +1,7 @@
 
 import json
 import numbers
+import syslog
 
 from time import sleep
 
@@ -23,6 +24,7 @@ class QLDBDriver:
 
 
     def execute(self, transaction_executor, statement):
+        syslog.syslog(f"CARGOPRODUCE: {statement}")
         cursor = transaction_executor.execute_statement(statement)
         
         return cursor
@@ -146,17 +148,12 @@ class QLDBDriver:
         raw_data = data
 
         while len(raw_data) > 0:
-            data_tmp = json.dumps(raw_data[:step])\
-                .replace("None", "null")\
-                .replace('""', "null")\
-                .replace("{", "`{")\
-                .replace("}", "}`")\
-                .replace("0.0", "0")\
-                .replace('"', "'")
+            data_tmp = str(raw_data[:step]).replace("None", "null")
 
             data_tmp = data_tmp[1:][:-1]
 
             statement = f"INSERT INTO {table_name} << {data_tmp} >>"
+
             self.execute_statement(statement)
 
             del raw_data[:step]
